@@ -36,6 +36,14 @@ public:
 
   bool is_set() const override { return true; }
 
+  void validate() const override {
+#ifndef ALLOW_EXCEPTIONS_AS_TYPE
+    if( get_elem_type()->get_true_type()->is_xception()) {
+      failure("exception type \"%s\" cannot be used inside a set", get_elem_type()->get_name().c_str());
+    }
+#endif
+  }
+
 private:
   t_type* elem_type_;
 };
