@@ -26,9 +26,9 @@ t_type* t_typedef::get_type() {
 }
 
 const t_type* t_typedef::get_type() const {
-  if (type_ == NULL) {
+  if (type_ == nullptr) {
     const t_type* type = get_program()->scope()->get_type(symbolic_);
-    if (type == NULL) {
+    if (type == nullptr) {
       printf("Type \"%s\" not defined\n", symbolic_.c_str());
       exit(1);
     }
