@@ -21,6 +21,10 @@ package org.apache.thrift;
 
 /** Requirement type constants. */
 public final class TFieldRequirementType {
+
+  /* no instantiation */
+  private TFieldRequirementType() {}
+
   public static final byte REQUIRED = 1;
   public static final byte OPTIONAL = 2;
   public static final byte DEFAULT = 3;
