@@ -23,14 +23,18 @@ using KellermanSoftware.CompareNetObjects;
 using Microsoft.VisualStudio.TestTools.UnitTesting;
 using Thrift.Protocol;
 using Thrift.Protocol.Entities;
+using Thrift.Transport;
 using Thrift.Transport.Client;
 
+#pragma warning disable IDE0063  // using
+
 namespace Thrift.IntegrationTests.Protocols
 {
     [TestClass]
     public class ProtocolsOperationsTests
     {
-        private readonly CompareLogic _compareLogic = new CompareLogic();
+        private readonly CompareLogic _compareLogic = new();
+        private static readonly TConfiguration Configuration = new();
 
         [DataTestMethod]
         [DataRow(typeof(TBinaryProtocol), TMessageType.Call)]
@@ -52,17 +56,18 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteMessageBeginAsync(expected);
-                    await protocol.WriteMessageEndAsync();
+                    await protocol.WriteMessageBeginAsync(expected, default);
+                    await protocol.WriteMessageEndAsync(default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream.Seek(0, SeekOrigin.Begin);
 
-                    var actualMessage = await protocol.ReadMessageBeginAsync();
-                    await protocol.ReadMessageEndAsync();
+                    var actualMessage = await protocol.ReadMessageBeginAsync(default);
+                    await protocol.ReadMessageEndAsync(default);
 
                     var result = _compareLogic.Compare(expected, actualMessage);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -86,17 +91,18 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteStructBeginAsync(expected);
-                    await protocol.WriteStructEndAsync();
+                    await protocol.WriteStructBeginAsync(expected, default);
+                    await protocol.WriteStructEndAsync(default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadStructBeginAsync();
-                    await protocol.ReadStructEndAsync();
+                    var actual = await protocol.ReadStructBeginAsync(default);
+                    await protocol.ReadStructEndAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -121,17 +127,18 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteFieldBeginAsync(expected);
-                    await protocol.WriteFieldEndAsync();
+                    await protocol.WriteFieldBeginAsync(expected, default);
+                    await protocol.WriteFieldEndAsync(default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadFieldBeginAsync();
-                    await protocol.ReadFieldEndAsync();
+                    var actual = await protocol.ReadFieldBeginAsync(default);
+                    await protocol.ReadFieldEndAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -154,17 +161,18 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteMapBeginAsync(expected);
-                    await protocol.WriteMapEndAsync();
+                    await protocol.WriteMapBeginAsync(expected, default);
+                    await protocol.WriteMapEndAsync(default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadMapBeginAsync();
-                    await protocol.ReadMapEndAsync();
+                    var actual = await protocol.ReadMapBeginAsync(default);
+                    await protocol.ReadMapEndAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -188,17 +196,18 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteListBeginAsync(expected);
-                    await protocol.WriteListEndAsync();
+                    await protocol.WriteListBeginAsync(expected, default);
+                    await protocol.WriteListEndAsync(default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadListBeginAsync();
-                    await protocol.ReadListEndAsync();
+                    var actual = await protocol.ReadListBeginAsync(default);
+                    await protocol.ReadListEndAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -221,17 +230,18 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteSetBeginAsync(expected);
-                    await protocol.WriteSetEndAsync();
+                    await protocol.WriteSetBeginAsync(expected, default);
+                    await protocol.WriteSetEndAsync(default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadSetBeginAsync();
-                    await protocol.ReadSetEndAsync();
+                    var actual = await protocol.ReadSetBeginAsync(default);
+                    await protocol.ReadSetEndAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -254,15 +264,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteBoolAsync(expected);
+                    await protocol.WriteBoolAsync(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadBoolAsync();
+                    var actual = await protocol.ReadBoolAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -285,15 +296,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteByteAsync(expected);
+                    await protocol.WriteByteAsync(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadByteAsync();
+                    var actual = await protocol.ReadByteAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -316,15 +328,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteI16Async(expected);
+                    await protocol.WriteI16Async(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadI16Async();
+                    var actual = await protocol.ReadI16Async(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -347,15 +360,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteI32Async(expected);
+                    await protocol.WriteI32Async(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadI32Async();
+                    var actual = await protocol.ReadI32Async(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -378,15 +392,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteI64Async(expected);
+                    await protocol.WriteI64Async(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadI64Async();
+                    var actual = await protocol.ReadI64Async(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -409,15 +424,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteDoubleAsync(expected);
+                    await protocol.WriteDoubleAsync(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadDoubleAsync();
+                    var actual = await protocol.ReadDoubleAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -440,15 +456,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteStringAsync(expected);
+                    await protocol.WriteStringAsync(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadStringAsync();
+                    var actual = await protocol.ReadStringAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -471,15 +488,16 @@ namespace Thrift.IntegrationTests.Protocols
             try
             {
                 var tuple = GetProtocolInstance(protocolType);
-                using (var stream = tuple.Item1)
+                using (var stream = tuple.Stream)
                 {
-                    var protocol = tuple.Item2;
+                    var protocol = tuple.Protocol;
 
-                    await protocol.WriteBinaryAsync(expected);
+                    await protocol.WriteBinaryAsync(expected, default);
+                    await tuple.Transport.FlushAsync(default);
 
                     stream?.Seek(0, SeekOrigin.Begin);
 
-                    var actual = await protocol.ReadBinaryAsync();
+                    var actual = await protocol.ReadBinaryAsync(default);
 
                     var result = _compareLogic.Compare(expected, actual);
                     Assert.IsTrue(result.AreEqual, result.DifferencesString);
@@ -491,12 +509,15 @@ namespace Thrift.IntegrationTests.Protocols
             }
         }
 
-        private static Tuple<Stream, TProtocol> GetProtocolInstance(Type protocolType)
+        private record struct ProtocolTransportStack(Stream Stream, TTransport Transport, TProtocol Protocol);
+
+        private static ProtocolTransportStack GetProtocolInstance(Type protocolType)
         {
             var memoryStream = new MemoryStream();
-            var streamClientTransport = new TStreamTransport(memoryStream, memoryStream);
-            var protocol = (TProtocol) Activator.CreateInstance(protocolType, streamClientTransport);
-            return new Tuple<Stream, TProtocol>(memoryStream, protocol);
+            var streamClientTransport = new TStreamTransport(memoryStream, memoryStream,Configuration);
+            if( Activator.CreateInstance(protocolType, streamClientTransport) is TProtocol protocol)
+                return new ProtocolTransportStack(memoryStream, streamClientTransport, protocol);
+            throw new Exception("Unexpected");
         }
     }
 }
