@@ -22,9 +22,11 @@ module.exports = InputBufferUnderrunError;
 
 function InputBufferUnderrunError(message) {
   Error.call(this);
-  Error.captureStackTrace(this, this.constructor);
+  if (Error.captureStackTrace !== undefined) {
+    Error.captureStackTrace(this, this.constructor);
+  }
   this.name = this.constructor.name;
   this.message = message;
-};
+}
 
 util.inherits(InputBufferUnderrunError, Error);
