@@ -30,7 +30,7 @@
 
 G_DEFINE_TYPE (ThriftTestHandler,
                thrift_test_handler,
-               T_TEST_TYPE_THRIFT_TEST_HANDLER);
+               T_TEST_TYPE_THRIFT_TEST_HANDLER)
 
 gboolean
 thrift_test_handler_test_void (TTestThriftTestIf  *iface,
@@ -59,6 +59,21 @@ thrift_test_handler_test_string (TTestThriftTestIf  *iface,
   return TRUE;
 }
 
+gboolean
+thrift_test_handler_test_bool (TTestThriftTestIf  *iface,
+                               gboolean           *_return,
+                               const gboolean      thing,
+                               GError            **error)
+{
+  THRIFT_UNUSED_VAR (iface);
+  THRIFT_UNUSED_VAR (error);
+
+  printf ("testBool(%s)\n", thing ? "true" : "false");
+  *_return = thing;
+
+  return TRUE;
+}
+
 gboolean
 thrift_test_handler_test_byte (TTestThriftTestIf  *iface,
                                gint8              *_return,
@@ -119,6 +134,22 @@ thrift_test_handler_test_double (TTestThriftTestIf  *iface,
   return TRUE;
 }
 
+gboolean 
+thrift_test_handler_test_binary (TTestThriftTestIf *iface,
+                                 GByteArray ** _return,
+                                 const GByteArray * thing,
+                                 GError **error)
+{
+  THRIFT_UNUSED_VAR (iface);
+  THRIFT_UNUSED_VAR (error);
+
+  printf ("testBinary()\n");  // TODO: hex output
+  g_byte_array_ref((GByteArray *)thing);
+  *_return = (GByteArray *)thing;
+
+  return TRUE;
+}
+
 gboolean
 thrift_test_handler_test_struct (TTestThriftTestIf  *iface,
                                  TTestXtruct       **_return,
@@ -336,7 +367,7 @@ thrift_test_handler_test_list (TTestThriftTestIf  *iface,
   printf ("testList({");
   for (i = 0; i < thing->len; i += 1) {
     gint32 value;
-    gint32 *new_value;
+    gint32 new_value;
 
     if (first)
       first = FALSE;
@@ -346,9 +377,8 @@ thrift_test_handler_test_list (TTestThriftTestIf  *iface,
     value = g_array_index (thing, gint32, i);
     printf ("%d", value);
 
-    new_value = g_malloc (sizeof *new_value);
-    *new_value = value;
-    g_array_append_val (*_return, *new_value);
+    new_value = value;
+    g_array_append_val (*_return, new_value);
   }
   printf ("})\n");
 
@@ -442,8 +472,6 @@ thrift_test_handler_test_insanity (TTestThriftTestIf    *iface,
                                    const TTestInsanity  *argument,
                                    GError              **error)
 {
-  TTestXtruct *hello;
-  TTestXtruct *goodbye;
   TTestXtruct *xtruct_in;
 
   gchar *string_thing = NULL;
@@ -453,7 +481,6 @@ thrift_test_handler_test_insanity (TTestThriftTestIf    *iface,
 
   GPtrArray *xtructs;
 
-  TTestInsanity *crazy;
   TTestInsanity *looney;
 
   GHashTable *user_map;
@@ -472,50 +499,10 @@ thrift_test_handler_test_insanity (TTestThriftTestIf    *iface,
   guint i;
 
   THRIFT_UNUSED_VAR (iface);
-  THRIFT_UNUSED_VAR (argument);
   THRIFT_UNUSED_VAR (error);
 
   printf ("testInsanity()\n");
 
-  hello = g_object_new (T_TEST_TYPE_XTRUCT,
-                        "string_thing", "Hello2",
-                        "byte_thing",   2,
-                        "i32_thing",    2,
-                        "i64_thing",    2,
-                        NULL);
-
-  goodbye = g_object_new (T_TEST_TYPE_XTRUCT,
-                          "string_thing", "Goodbye4",
-                          "byte_thing",   4,
-                          "i32_thing",    4,
-                          "i64_thing",    4,
-                          NULL);
-
-  crazy = g_object_new (T_TEST_TYPE_INSANITY, NULL);
-  g_object_get (crazy,
-                "userMap", &user_map,
-                "xtructs", &xtructs,
-                NULL);
-
-  user_id = g_malloc(sizeof *user_id);
-  *user_id = 8;
-  g_hash_table_insert (user_map,
-                       GINT_TO_POINTER (T_TEST_NUMBERZ_EIGHT),
-                       user_id);
-
-  g_ptr_array_add (xtructs, goodbye);
-
-  user_id = g_malloc(sizeof *user_id);
-  *user_id = 5;
-  g_hash_table_insert (user_map,
-                       GINT_TO_POINTER (T_TEST_NUMBERZ_FIVE),
-                       user_id);
-
-  g_ptr_array_add (xtructs, hello);
-
-  g_hash_table_unref (user_map);
-  g_ptr_array_unref (xtructs);
-
   first_map = g_hash_table_new_full (g_direct_hash,
                                      g_direct_equal,
                                      NULL,
@@ -527,17 +514,21 @@ thrift_test_handler_test_insanity (TTestThriftTestIf    *iface,
 
   g_hash_table_insert (first_map,
                        GINT_TO_POINTER (T_TEST_NUMBERZ_TWO),
-                       crazy);
+                       (gpointer)argument);
   g_hash_table_insert (first_map,
                        GINT_TO_POINTER (T_TEST_NUMBERZ_THREE),
-                       crazy);
+                       (gpointer)argument);
 
-  /* Increment crazy's ref count since first_map now holds two
-     references to it and would otherwise attempt to deallocate it
-     twice during destruction. We do this instead of creating a copy
-     of crazy in order to mimic the C++ implementation (and since,
-     frankly, the world needs less crazy, not more). */
-  g_object_ref (crazy);
+  /* Increment argument's ref count by two because first_map now holds
+     two references to it and the caller is not aware we have made any
+     additional references to argument.  (That is, caller owns argument
+     and will unref it explicitly in addition to unref-ing *_return.)
+
+     We do this instead of creating a copy of argument in order to mimic
+     the C++ implementation (and since, frankly, the world needs less
+     argument, not more). */
+  g_object_ref ((gpointer)argument);
+  g_object_ref ((gpointer)argument);
 
   looney = g_object_new (T_TEST_TYPE_INSANITY, NULL);
   g_hash_table_insert (second_map,
@@ -599,6 +590,9 @@ thrift_test_handler_test_insanity (TTestThriftTestIf    *iface,
                 byte_thing,
                 i32_thing,
                 i64_thing);
+        if (string_thing != NULL) {
+          g_free (string_thing);
+        }
       }
       printf ("}");
       g_ptr_array_unref (xtructs);
@@ -632,10 +626,10 @@ thrift_test_handler_test_multi (TTestThriftTestIf   *iface,
   printf ("testMulti()\n");
 
   g_object_set (*_return,
-                "string_thing", g_strdup ("Hello2"),
-                "byte_thing",   arg0,
-                "i32_thing",    arg1,
-                "i64_thing",    arg2,
+                "string_thing", "Hello2",
+                "byte_thing",    arg0,
+                "i32_thing",     arg1,
+                "i64_thing",     arg2,
                 NULL);
 
   return TRUE;
@@ -662,7 +656,7 @@ thrift_test_handler_test_exception (TTestThriftTestIf  *iface,
        argument, set *error to NULL and return FALSE */
     *err1 = g_object_new (T_TEST_TYPE_XCEPTION,
                           "errorCode", 1001,
-                          "message",   g_strdup (arg),
+                          "message",   arg,
                           NULL);
     *error = NULL;
     result = FALSE;
@@ -684,7 +678,7 @@ thrift_test_handler_test_exception (TTestThriftTestIf  *iface,
     /* This code is duplicated from the C++ test suite, though it
        appears to serve no purpose */
     xtruct = g_object_new (T_TEST_TYPE_XTRUCT,
-                           "string_thing", g_strdup (arg),
+                           "string_thing", arg,
                            NULL);
     g_object_unref (xtruct);
 
@@ -714,22 +708,23 @@ thrift_test_handler_test_multi_exception (TTestThriftTestIf  *iface,
   g_assert (*err1 == NULL);
   g_assert (*err2 == NULL);
 
-  if (strncmp (arg0, "Xception", 9) == 0) {
+  if (strncmp (arg0, "Xception", 8) == 0 && strlen(arg0) == 8) {
     *err1 = g_object_new (T_TEST_TYPE_XCEPTION,
                           "errorCode", 1001,
-                          "message",   g_strdup ("This is an Xception"),
+                          "message",  "This is an Xception",
                           NULL);
     result = FALSE;
   }
-  else if (strncmp (arg0, "Xception2", 10) == 0) {
+  else if (strncmp (arg0, "Xception2", 9) == 0) {
     *err2 = g_object_new (T_TEST_TYPE_XCEPTION2,
-                          "errorCode", 2002);
+                          "errorCode", 2002,
+                          NULL);
 
     g_object_get (*err2,
                   "struct_thing", &struct_thing,
                   NULL);
     g_object_set (struct_thing,
-                  "string_thing", g_strdup ("This is an Xception2"),
+                  "string_thing", "This is an Xception2",
                   NULL);
     g_object_set (*err2,
                   "struct_thing", struct_thing,
@@ -740,7 +735,7 @@ thrift_test_handler_test_multi_exception (TTestThriftTestIf  *iface,
   }
   else {
     g_object_set (*_return,
-                  "string_thing", g_strdup (arg1),
+                  "string_thing", arg1,
                   NULL);
     result = TRUE;
   }
@@ -781,6 +776,9 @@ thrift_test_handler_class_init (ThriftTestHandlerClass *klass)
   base_class->test_string =
     klass->test_string =
     thrift_test_handler_test_string;
+  base_class->test_bool =
+    klass->test_bool =
+    thrift_test_handler_test_bool;
   base_class->test_byte =
     klass->test_byte =
     thrift_test_handler_test_byte;
@@ -793,6 +791,9 @@ thrift_test_handler_class_init (ThriftTestHandlerClass *klass)
   base_class->test_double =
     klass->test_double =
     thrift_test_handler_test_double;
+  base_class->test_binary =
+    klass->test_binary =
+    thrift_test_handler_test_binary;
   base_class->test_struct =
     klass->test_struct =
     thrift_test_handler_test_struct;
