@@ -21,7 +21,6 @@ import copy
 import multiprocessing
 import os
 import sys
-from .compat import path_join
 from .util import merge_dict, domain_socket_path
 
 
@@ -50,7 +49,7 @@ class TestProgram(object):
     def _fix_cmd_path(self, cmd):
         # if the arg is a file in the current directory, make it path
         def abs_if_exists(arg):
-            p = path_join(self.workdir, arg)
+            p = os.path.join(self.workdir, arg)
             return p if os.path.exists(p) else arg
 
         if cmd[0] == 'python':
@@ -125,7 +124,7 @@ class TestEntry(object):
         if os.path.isabs(path):
             path = os.path.realpath(path)
         else:
-            path = os.path.realpath(path_join(self.testdir, path))
+            path = os.path.realpath(os.path.join(self.testdir, path))
         config.update({key: path})
         return config
 
