@@ -100,7 +100,7 @@ G_END_DECLS
 
 G_DEFINE_TYPE (TutorialCalculatorHandler,
                tutorial_calculator_handler,
-               TYPE_CALCULATOR_HANDLER);
+               TYPE_CALCULATOR_HANDLER)
 
 /* Each of a handler's methods accepts at least two parameters: A
    pointer to the service-interface implementation (the handler object
@@ -108,7 +108,7 @@ G_DEFINE_TYPE (TutorialCalculatorHandler,
    about any error that occurs.
 
    On success, a handler method returns TRUE. A return value of FALSE
-   indicates an error occured and the error parameter has been
+   indicates an error occurred and the error parameter has been
    set. (Methods should not return FALSE without first setting the
    error parameter.) */
 static gboolean
@@ -173,8 +173,6 @@ tutorial_calculator_handler_calculate (CalculatorIf      *iface,
                                        InvalidOperation **ouch,
                                        GError           **error)
 {
-  THRIFT_UNUSED_VAR (error);
-
   TutorialCalculatorHandler *self;
 
   gint *log_key;
@@ -186,6 +184,8 @@ tutorial_calculator_handler_calculate (CalculatorIf      *iface,
   Operation op;
   gboolean result = TRUE;
 
+  THRIFT_UNUSED_VAR (error);
+
   g_return_val_if_fail (IS_TUTORIAL_CALCULATOR_HANDLER (iface),
                         FALSE);
   self = TUTORIAL_CALCULATOR_HANDLER (iface);
@@ -231,7 +231,7 @@ tutorial_calculator_handler_calculate (CalculatorIf      *iface,
          setting the corresponding output parameter to a new instance
          of its type and returning FALSE. */
       *ouch = g_object_new (TYPE_INVALID_OPERATION,
-                            "what", op,
+                            "whatOp", op,
                             "why",  g_strdup ("Cannot divide by 0"),
                             NULL);
       result = FALSE;
@@ -249,7 +249,7 @@ tutorial_calculator_handler_calculate (CalculatorIf      *iface,
 
   default:
     *ouch = g_object_new (TYPE_INVALID_OPERATION,
-                          "what", op,
+                          "whatOp", op,
                           "why",  g_strdup ("Invalid Operation"),
                           NULL);
     result = FALSE;
@@ -300,14 +300,14 @@ tutorial_calculator_handler_get_struct (SharedServiceIf  *iface,
                                         const gint32      key32,
                                         GError          **error)
 {
-  THRIFT_UNUSED_VAR (error);
-
   gint key = (gint)key32;
   TutorialCalculatorHandler *self;
   SharedStruct *log_struct;
   gint log_key;
   gchar *log_value;
 
+  THRIFT_UNUSED_VAR (error);
+
   g_return_val_if_fail (IS_TUTORIAL_CALCULATOR_HANDLER (iface),
                         FALSE);
   self = TUTORIAL_CALCULATOR_HANDLER (iface);
@@ -440,7 +440,7 @@ int main (void)
 
   struct sigaction sigint_action;
 
-  GError *error;
+  GError *error = NULL;
   int exit_status = 0;
 
 #if (!GLIB_CHECK_VERSION (2, 36, 0))
